@@ -32,6 +32,10 @@ class FluxTable(FluxStructure):
         cls_name = type(self).__name__
         return cls_name + "() columns: " + str(len(self.columns)) + ", records: " + str(len(self.records))
 
+    def __repr__(self):
+        """Format for inspection."""
+        return f"<{type(self).__name__}: {len(self.columns)} columns, {len(self.records)} records>"
+
     def __iter__(self):
         """Iterate over records."""
         return iter(self.records)
@@ -48,6 +52,15 @@ class FluxColumn(FluxStructure):
         self.label = label
         self.index = index
 
+    def __repr__(self):
+        """Format for inspection."""
+        fields = [repr(self.index)] + [
+            f'{name}={getattr(self, name)!r}' for name in (
+                'label', 'data_type', 'group', 'default_value'
+            ) if getattr(self, name) is not None
+        ]
+        return f"{type(self).__name__}({', '.join(fields)})"
+
 
 class FluxRecord(FluxStructure):
     """A record is a tuple of named values and is represented using an object type."""
@@ -95,3 +108,7 @@ class FluxRecord(FluxStructure):
         """Return formatted output."""
         cls_name = type(self).__name__
         return cls_name + "() table: " + str(self.table) + ", " + str(self.values)
+
+    def __repr__(self):
+        """Format for inspection."""
+        return f"<{type(self).__name__}: field={self.values.get('_field')}, value={self.values.get('_value')}>"
